a:link {
	color:#0035C7;
}

a:visited {
	color:#54638C;
}

h1 {
	color:#C70036;
}

div.producttitle {
	color:#C70036;
}

.section h1.title {
	color:#C70036;
}

.docnav.top li.home {
            color: #C70036;
}

h2,h3,h4,h5,h6 {
	color:#C70036;
}

table {
	border:1px solid #aaa;
}

table th {
	background-color:#900;
}

table tr.even td {
	background-color:#f5f5f5;
}

#title a {
	height:54px;
}

.term{
	color:#C70036;
}

.revhistory table th {
	color:#C70036;
}

.titlepage .edition {
	color: #C70036;
}

span.remark{
	background-color: #ffff00;
}


/* Disable the important formatting on sidebars. */
div.important.sidebar:before {
    content: "";
}

/* Styles of block URLs */
div.url {
    margin-top: 0.5em;
}
div.url + div.url {
    margin-top: 0;
}

/* Styles of sidebars */
div.sidebar {
    border: 2px solid #aaaaaa;
    margin-top: 10px;
    margin-bottom: 10px;
    padding: 10px;
    font-size: 90%;
    background-color: #eeeeee;
}

div.sidebar > div.titlepage {
    border-bottom: 1px solid;
}

div.sidebar > div.titlepage span.emphasis:nth-child(1) > em {
    color: #666666;
    font-style: normal;
    font-variant: small-caps;
}

/* Modify behaviour within sidebars */
div.sidebar p.title {
    margin-top: 0;
    margin-bottom: 0;
}
div.sidebar > p, div.sidebar > div.para {
    margin-top: 1em;
    margin-bottom: 0;
}
div.sidebar h6 {
    margin-top: 0px;
}

/* Styles of screens */
.screen .computeroutput {
    font-weight: normal;
}
